@@ -13,11 +13,11 @@ LWP::Curl - LWP methods implementation with Curl engine
 
 =head1 VERSION
 
-Version 0.05
+Version 0.07
 
 =cut
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 =head1 SYNOPSIS
 
@@ -67,6 +67,20 @@ Turn on/off auto encode urls, for get/post.
 
 Set how deep the spider will follow  when receive HTTP 301 ( Redirect ). The default is 3.
 
+=item * C<< proxy => $proxyurl >>
+
+Set the proxy in the constructor, $proxyurl will be like:  
+    http://myproxy.com:3128/
+    http://username:password@proxy.com:3128/
+
+  libcurl respects the environment variables http_proxy, ftp_proxy,
+  all_proxy etc, if any of those are set. The $lwpcurl->proxy option does
+  however override any possibly set environment variables. 
+
+=item * C<< cookie_jar => number >>
+
+Set how deep the spider will follow  when receive HTTP 301 ( Redirect ). The default is 3.
+
 =back
 
 =cut
@@ -104,6 +118,9 @@ sub new {
 	
 	$self->{timeout} = $timeout;	
    
+    my $proxy = delete $args{proxy};
+    $self->{proxy} = undef unless defined $proxy;
+    
     $self->{retcode} = undef;
 
     my $debug = delete $args{debug};
@@ -117,8 +134,8 @@ sub new {
     $self->{agent}->setopt( CURLOPT_MAXREDIRS,   $maxredirs );
     $self->{agent}->setopt( CURLOPT_FOLLOWLOCATION, $followlocation );
     $self->{agent}->setopt( CURLOPT_SSL_VERIFYPEER, 0 );
-
-    #CURLOPT_COOKIESESSION,$cookie;
+    $self->{agent}->setopt( CURLOPT_VERBOSE, 0 ); #ubuntu bug
+    $self->{agent}->setopt( CURLOPT_PROXY, $proxy ) if $proxy;
 
     return bless $self, $class;
 }
@@ -154,7 +171,7 @@ sub get {
     $self->{retcode} = $self->{agent}->perform;
 
     if ( $self->{retcode} == 0 ) {
-        #print("\nTransfer went ok\n") if $self->{debug};
+        print("\nTransfer went ok\n") if $self->{debug};
         return $content;
     }
     else {
@@ -208,8 +225,8 @@ sub post {
         #print STDERR "var: $var - $hash_form->{$var}\n";
     }
 
-    $url         = encode($url)         if $self->{auto_encode};
-    $post_string = encode($post_string) if $self->{auto_encode};
+	$url = uri_escape($url,"[^:./]") if $self->{auto_encode};
+	$post_string = uri_escape($post_string,"[^:./]") if $self->{auto_encode};
 
     $self->{agent}->setopt( CURLOPT_POSTFIELDS, $post_string );
     $self->{agent}->setopt( CURLOPT_POST,       1 );
@@ -330,6 +347,55 @@ sub agent_alias {
     }
 }
 
+=head2 $lwpcurl->proxy($proxyurl)
+
+Set the proxy in the constructor, $proxyurl will be like:  
+    http://myproxy.com:3128/
+    http://username:password@proxy.com:3128/
+
+libcurl respects the environment variables http_proxy, ftp_proxy,
+all_proxy etc, if any of those are set. The $lwpcurl->proxy option does
+however override any possibly set environment variables. 
+
+To disable proxy set $lwpcurl->proxy('');
+
+$lwpcurl->proxy without argument, return the current proxy
+
+=cut
+
+sub proxy {
+    my ( $self, $proxy ) = @_;
+    if ( !$proxy ) {
+        return $self->{proxy};
+    }
+	$self->{proxy} = $proxy;
+    $self->{agent}->setopt( CURLOPT_PROXY, $self->proxy );
+}
+
+=head2 $lwpcurl->cookie_jar($proxyurl)
+
+Set the proxy in the constructor, $proxyurl will be like:  
+    http://myproxy.com:3128/
+    http://username:password@proxy.com:3128/
+
+libcurl respects the environment variables http_proxy, ftp_proxy,
+all_proxy etc, if any of those are set. The $lwpcurl->proxy option does
+however override any possibly set environment variables. 
+
+To disable proxy set $lwpcurl->proxy('');
+
+$lwpcurl->proxy without argument, return the current proxy
+
+=cut
+
+sub cookie_jar {
+    my ( $self, $proxy ) = @_;
+    if ( !$proxy ) {
+        return $self->{proxy};
+    }
+	$self->{proxy} = $proxy;
+    $self->{agent}->setopt( CURLOPT_PROXY, $self->proxy );
+}
 =head1 TODO
 
 This is a small list of features I'm plan to add. Feel free to contribute with your wishlist and comentaries!
@@ -342,8 +408,6 @@ This is a small list of features I'm plan to add. Feel free to contribute with y
 
 =item * Support Cookies
 
-=item * Support Proxys
-
 =item * PASS in all tests of LWP
 
 =item * Make a patch to L<WWW::Mechanize>, todo change engine, like "new(engine => 'LWP::Curl')"
@@ -393,10 +457,11 @@ L<http://search.cpan.org/dist/LWP-Curl>
 =head1 ACKNOWLEDGEMENTS
 
 Thanks to Breno G. Oliveira for the great tips.    
+Thanks for the LWP and WWW::Mechanize for the inspiration.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2008 Lindolfo Rodrigues de Oliveira Neto, all rights reserved.
+Copyright 2009 Lindolfo Rodrigues de Oliveira Neto, all rights reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
